0.9.9 API documentation: quaternion_common.hpp File Reference

| 0.9.9 API documentation

- Main Page
- Modules
- Files

- File List

Functions
quaternion_common.hpp File Reference

GLM_EXT_quaternion_common More...

Go to the source code of this file.

## Functions
template<typename T , qualifier Q>
GLM_FUNC_DECL qua< T, Q > | conjugate (qua< T, Q > const &q)
| Returns the q conjugate. More...
template<typename T , qualifier Q>
GLM_FUNC_DECL qua< T, Q > | inverse (qua< T, Q > const &q)
| Returns the q inverse. More...
template<typename T , qualifier Q>
GLM_FUNC_DECL vec< 4, bool, Q > | isinf (qua< T, Q > const &x)
| Returns true if x holds a positive infinity or negative infinity representation in the underlying implementation's set of floating point representations. More...
template<typename T , qualifier Q>
GLM_FUNC_DECL vec< 4, bool, Q > | isnan (qua< T, Q > const &x)
| Returns true if x holds a NaN (not a number) representation in the underlying implementation's set of floating point representations. More...
template<typename T , qualifier Q>
GLM_FUNC_DECL qua< T, Q > | lerp (qua< T, Q > const &x, qua< T, Q > const &y, T a)
| Linear interpolation of two quaternions. More...
template<typename T , qualifier Q>
GLM_FUNC_DECL qua< T, Q > | mix (qua< T, Q > const &x, qua< T, Q > const &y, T a)
| Spherical linear interpolation of two quaternions. More...
template<typename T , qualifier Q>
GLM_FUNC_DECL qua< T, Q > | slerp (qua< T, Q > const &x, qua< T, Q > const &y, T a)
| Spherical linear interpolation of two quaternions. More...

## Detailed Description

GLM_EXT_quaternion_common

Definition in file quaternion_common.hpp.